==> openshift-model-hive-6.13.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterClaimStatusFluent.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterClaimStatusFluent<A extends ClusterClaimStatusFluent<A>> extends BaseFluent<A>{
  public ClusterClaimStatusFluent() {
  }
  
  public ClusterClaimStatusFluent(ClusterClaimStatus instance) {
    this.copyInstance(instance);
  }
  private ArrayList<ClusterClaimConditionBuilder> conditions = new ArrayList<ClusterClaimConditionBuilder>();
  private Duration lifetime;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ClusterClaimStatus instance) {
    instance = (instance != null ? instance : new ClusterClaimStatus());
    if (instance != null) {
          this.withConditions(instance.getConditions());
          this.withLifetime(instance.getLifetime());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToConditions(int index,ClusterClaimCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<ClusterClaimConditionBuilder>();}
    ClusterClaimConditionBuilder builder = new ClusterClaimConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").add(index, builder); conditions.add(index, builder);}
    return (A)this;
  }
  
  public A setToConditions(int index,ClusterClaimCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<ClusterClaimConditionBuilder>();}
    ClusterClaimConditionBuilder builder = new ClusterClaimConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").set(index, builder); conditions.set(index, builder);}
    return (A)this;
  }
  
  public A addToConditions(io.fabric8.openshift.api.model.hive.v1.ClusterClaimCondition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<ClusterClaimConditionBuilder>();}
    for (ClusterClaimCondition item : items) {ClusterClaimConditionBuilder builder = new ClusterClaimConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A addAllToConditions(Collection<ClusterClaimCondition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<ClusterClaimConditionBuilder>();}
    for (ClusterClaimCondition item : items) {ClusterClaimConditionBuilder builder = new ClusterClaimConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A removeFromConditions(io.fabric8.openshift.api.model.hive.v1.ClusterClaimCondition... items) {
    if (this.conditions == null) return (A)this;
    for (ClusterClaimCondition item : items) {ClusterClaimConditionBuilder builder = new ClusterClaimConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeAllFromConditions(Collection<ClusterClaimCondition> items) {
    if (this.conditions == null) return (A)this;
    for (ClusterClaimCondition item : items) {ClusterClaimConditionBuilder builder = new ClusterClaimConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromConditions(Predicate<ClusterClaimConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<ClusterClaimConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      ClusterClaimConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ClusterClaimCondition> buildConditions() {
    return this.conditions != null ? build(conditions) : null;
  }
  
  public ClusterClaimCondition buildCondition(int index) {
    return this.conditions.get(index).build();
  }
  
  public ClusterClaimCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  
  public ClusterClaimCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  
  public ClusterClaimCondition buildMatchingCondition(Predicate<ClusterClaimConditionBuilder> predicate) {
      for (ClusterClaimConditionBuilder item : conditions) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingCondition(Predicate<ClusterClaimConditionBuilder> predicate) {
      for (ClusterClaimConditionBuilder item : conditions) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withConditions(List<ClusterClaimCondition> conditions) {
    if (this.conditions != null) {
      this._visitables.get("conditions").clear();
    }
    if (conditions != null) {
        this.conditions = new ArrayList();
        for (ClusterClaimCondition item : conditions) {
          this.addToConditions(item);
        }
    } else {
      this.conditions = null;
    }
    return (A) this;
  }
  
  public A withConditions(io.fabric8.openshift.api.model.hive.v1.ClusterClaimCondition... conditions) {
    if (this.conditions != null) {
        this.conditions.clear();
        _visitables.remove("conditions");
    }
    if (conditions != null) {
      for (ClusterClaimCondition item : conditions) {
        this.addToConditions(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasConditions() {
    return this.conditions != null && !this.conditions.isEmpty();
  }
  
  public ConditionsNested<A> addNewCondition() {
    return new ConditionsNested(-1, null);
  }
  
  public ConditionsNested<A> addNewConditionLike(ClusterClaimCondition item) {
    return new ConditionsNested(-1, item);
  }
  
  public ConditionsNested<A> setNewConditionLike(int index,ClusterClaimCondition item) {
    return new ConditionsNested(index, item);
  }
  
  public ConditionsNested<A> editCondition(int index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  
  public ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editMatchingCondition(Predicate<ClusterClaimConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public Duration getLifetime() {
    return this.lifetime;
  }
  
  public A withLifetime(Duration lifetime) {
    this.lifetime = lifetime;
    return (A) this;
  }
  
  public boolean hasLifetime() {
    return this.lifetime != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterClaimStatusFluent that = (ClusterClaimStatusFluent) o;
    if (!java.util.Objects.equals(conditions, that.conditions)) return false;
    if (!java.util.Objects.equals(lifetime, that.lifetime)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(conditions,  lifetime,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (lifetime != null) { sb.append("lifetime:"); sb.append(lifetime + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ConditionsNested<N> extends ClusterClaimConditionFluent<ConditionsNested<N>> implements Nested<N>{
    ConditionsNested(int index,ClusterClaimCondition item) {
      this.index = index;
      this.builder = new ClusterClaimConditionBuilder(this, item);
    }
    ClusterClaimConditionBuilder builder;
    int index;
    
    public N and() {
      return (N) ClusterClaimStatusFluent.this.setToConditions(index,builder.build());
    }
    
    public N endCondition() {
      return and();
    }
    
  
  }

}

==> openshift-model-hive-7.0.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterClaimStatusFluent.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterClaimStatusFluent<A extends ClusterClaimStatusFluent<A>> extends BaseFluent<A>{
  public ClusterClaimStatusFluent() {
  }
  
  public ClusterClaimStatusFluent(ClusterClaimStatus instance) {
    this.copyInstance(instance);
  }
  private ArrayList<ClusterClaimConditionBuilder> conditions = new ArrayList<ClusterClaimConditionBuilder>();
  private String lifetime;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ClusterClaimStatus instance) {
    instance = (instance != null ? instance : new ClusterClaimStatus());
    if (instance != null) {
          this.withConditions(instance.getConditions());
          this.withLifetime(instance.getLifetime());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToConditions(int index,ClusterClaimCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<ClusterClaimConditionBuilder>();}
    ClusterClaimConditionBuilder builder = new ClusterClaimConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").add(index, builder); conditions.add(index, builder);}
    return (A)this;
  }
  
  public A setToConditions(int index,ClusterClaimCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<ClusterClaimConditionBuilder>();}
    ClusterClaimConditionBuilder builder = new ClusterClaimConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").set(index, builder); conditions.set(index, builder);}
    return (A)this;
  }
  
  public A addToConditions(io.fabric8.openshift.api.model.hive.v1.ClusterClaimCondition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<ClusterClaimConditionBuilder>();}
    for (ClusterClaimCondition item : items) {ClusterClaimConditionBuilder builder = new ClusterClaimConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A addAllToConditions(Collection<ClusterClaimCondition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<ClusterClaimConditionBuilder>();}
    for (ClusterClaimCondition item : items) {ClusterClaimConditionBuilder builder = new ClusterClaimConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A removeFromConditions(io.fabric8.openshift.api.model.hive.v1.ClusterClaimCondition... items) {
    if (this.conditions == null) return (A)this;
    for (ClusterClaimCondition item : items) {ClusterClaimConditionBuilder builder = new ClusterClaimConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeAllFromConditions(Collection<ClusterClaimCondition> items) {
    if (this.conditions == null) return (A)this;
    for (ClusterClaimCondition item : items) {ClusterClaimConditionBuilder builder = new ClusterClaimConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromConditions(Predicate<ClusterClaimConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<ClusterClaimConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      ClusterClaimConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ClusterClaimCondition> buildConditions() {
    return this.conditions != null ? build(conditions) : null;
  }
  
  public ClusterClaimCondition buildCondition(int index) {
    return this.conditions.get(index).build();
  }
  
  public ClusterClaimCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  
  public ClusterClaimCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  
  public ClusterClaimCondition buildMatchingCondition(Predicate<ClusterClaimConditionBuilder> predicate) {
      for (ClusterClaimConditionBuilder item : conditions) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingCondition(Predicate<ClusterClaimConditionBuilder> predicate) {
      for (ClusterClaimConditionBuilder item : conditions) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withConditions(List<ClusterClaimCondition> conditions) {
    if (this.conditions != null) {
      this._visitables.get("conditions").clear();
    }
    if (conditions != null) {
        this.conditions = new ArrayList();
        for (ClusterClaimCondition item : conditions) {
          this.addToConditions(item);
        }
    } else {
      this.conditions = null;
    }
    return (A) this;
  }
  
  public A withConditions(io.fabric8.openshift.api.model.hive.v1.ClusterClaimCondition... conditions) {
    if (this.conditions != null) {
        this.conditions.clear();
        _visitables.remove("conditions");
    }
    if (conditions != null) {
      for (ClusterClaimCondition item : conditions) {
        this.addToConditions(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasConditions() {
    return this.conditions != null && !this.conditions.isEmpty();
  }
  
  public ConditionsNested<A> addNewCondition() {
    return new ConditionsNested(-1, null);
  }
  
  public ConditionsNested<A> addNewConditionLike(ClusterClaimCondition item) {
    return new ConditionsNested(-1, item);
  }
  
  public ConditionsNested<A> setNewConditionLike(int index,ClusterClaimCondition item) {
    return new ConditionsNested(index, item);
  }
  
  public ConditionsNested<A> editCondition(int index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  
  public ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editMatchingCondition(Predicate<ClusterClaimConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public String getLifetime() {
    return this.lifetime;
  }
  
  public A withLifetime(String lifetime) {
    this.lifetime = lifetime;
    return (A) this;
  }
  
  public boolean hasLifetime() {
    return this.lifetime != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterClaimStatusFluent that = (ClusterClaimStatusFluent) o;
    if (!java.util.Objects.equals(conditions, that.conditions)) return false;
    if (!java.util.Objects.equals(lifetime, that.lifetime)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(conditions,  lifetime,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (lifetime != null) { sb.append("lifetime:"); sb.append(lifetime + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ConditionsNested<N> extends ClusterClaimConditionFluent<ConditionsNested<N>> implements Nested<N>{
    ConditionsNested(int index,ClusterClaimCondition item) {
      this.index = index;
      this.builder = new ClusterClaimConditionBuilder(this, item);
    }
    ClusterClaimConditionBuilder builder;
    int index;
    
    public N and() {
      return (N) ClusterClaimStatusFluent.this.setToConditions(index,builder.build());
    }
    
    public N endCondition() {
      return and();
    }
    
  
  }

}
